@@ -15,7 +15,7 @@ static int pid_wait(lua_State *L) {
 
 static int pid_wait(lua_State *L) {
   int status;
-  pid_t pid = luaL_checkint(L, 1);
+  pid_t pid = (pid_t)luaL_checkinteger(L, 1);
   /* Work around libuv bug that leaves defunct children:
    * https://github.com/libuv/libuv/issues/154 */
   while (!kill(pid, 0)) waitpid(pid, &status, WNOHANG);
@@ -31,7 +31,7 @@ static const luaL_Reg native_lib_f[] = {
 int luaopen_nvim_native(lua_State *L) {
   lua_newtable(L);
 #if LUA_VERSION_NUM >= 502
-  luaL_setfuncs(L, native_lib_f, NULL);
+  luaL_setfuncs(L, native_lib_f, 0);
 #else
   luaL_register(L, NULL, native_lib_f);
 #endif
